@@ -1,6 +1,6 @@
 // MIT License
 //
-// Copyright (c) 2017-2023 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2017-2024 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -300,10 +300,8 @@ struct custom_op2
 typedef ::testing::Types<params_subtract<unsigned int, int, hipcub::Sum, 64U, 1>,
                          params_subtract<int, bool, custom_op1, 128U, 1>,
                          params_subtract<float, int, custom_op2, 256U, 1>,
-#ifndef __HIP_PLATFORM_NVIDIA__
                          params_subtract<test_utils::half, int, custom_op1, 256U, 1>,
                          params_subtract<test_utils::bfloat16, int, custom_op2, 256U, 1>,
-#endif
                          params_subtract<int, bool, custom_op1, 256U, 1>,
 
                          params_subtract<float, int, hipcub::Sum, 37U, 1>,
@@ -900,9 +898,12 @@ TYPED_TEST(HipcubBlockAdjacentDifferenceSubtract, SubtractLeft)
                 hipMemcpyDeviceToHost
             )
         );
-        
-        ASSERT_NO_FATAL_FAILURE(test_utils::assert_near(
-            output, expected, test_utils::precision_threshold<type>::percentage));
+
+        ASSERT_NO_FATAL_FAILURE(
+            test_utils::assert_near(output,
+                                    expected,
+                                    std::max(test_utils::precision<type>::value,
+                                             test_utils::precision<stored_type>::value)));
 
         HIP_CHECK(hipFree(d_input));
         HIP_CHECK(hipFree(d_output));
@@ -1018,9 +1019,12 @@ TYPED_TEST(HipcubBlockAdjacentDifferenceSubtract, SubtractLeftPartialTile)
                 hipMemcpyDeviceToHost
             )
         );
-        
-        ASSERT_NO_FATAL_FAILURE(test_utils::assert_near(
-            output, expected, test_utils::precision_threshold<type>::percentage));
+
+        ASSERT_NO_FATAL_FAILURE(
+            test_utils::assert_near(output,
+                                    expected,
+                                    std::max(test_utils::precision<type>::value,
+                                             test_utils::precision<stored_type>::value)));
 
         HIP_CHECK(hipFree(d_input));
         HIP_CHECK(hipFree(d_tile_sizes));
@@ -1118,9 +1122,12 @@ TYPED_TEST(HipcubBlockAdjacentDifferenceSubtract, SubtractRight)
                 hipMemcpyDeviceToHost
             )
         );
-        
-        ASSERT_NO_FATAL_FAILURE(test_utils::assert_near(
-            output, expected, test_utils::precision_threshold<type>::percentage));
+
+        ASSERT_NO_FATAL_FAILURE(
+            test_utils::assert_near(output,
+                                    expected,
+                                    std::max(test_utils::precision<type>::value,
+                                             test_utils::precision<stored_type>::value)));
 
         HIP_CHECK(hipFree(d_input));
         HIP_CHECK(hipFree(d_output));
@@ -1235,9 +1242,16 @@ TYPED_TEST(HipcubBlockAdjacentDifferenceSubtract, SubtractRightPartialTile)
                 hipMemcpyDeviceToHost
             )
         );
-        
-        ASSERT_NO_FATAL_FAILURE(test_utils::assert_near(
-            output, expected, test_utils::precision_threshold<type>::percentage));
+
+        using is_add_op = test_utils::is_add_operator<binary_function>;
+        // clang-format off
+        ASSERT_NO_FATAL_FAILURE(test_utils::assert_near(output, expected,
+            is_add_op::value
+                ? std::max(test_utils::precision<type>::value, test_utils::precision<stored_type>::value)
+                : std::is_same<type, stored_type>::value 
+                    ? 0 
+                    : test_utils::precision<stored_type>::value));
+        // clang-format on
 
         HIP_CHECK(hipFree(d_input));
         HIP_CHECK(hipFree(d_tile_sizes));
